@@ -24,8 +24,8 @@ sys.path.insert(0, libdir)
 import pycdio
 import cdio
 
-def print_cdtext_track_info(device, track, message):
-    print message
+def print_cdtext_track_info_old(device, track, message):
+    print(message)
     t = device.get_track(track)
     cdt = t.get_cdtext()
 
@@ -33,26 +33,51 @@ def print_cdtext_track_info(device, track, message):
         value = cdt.get(i)
         # value can be empty but exist, compared to NULL values
         if value is not None:
-            print "\t%s: %s" % (pycdio.cdtext_field2str(i), value)
+            print("\t%s: %s" % (pycdio.cdtext_field2str(i), value))
+            pass
+        pass
+    return
+
+def print_cdtext_info_new(device, message):
+    print(message)
+    cdt = device.get_cdtext()
+    i_tracks = device.get_num_tracks()
+    i_first_track = pycdio.get_first_track_num(device.cd)
+
+    for t in range(i_first_track, i_tracks + i_first_track):
+        for i in range(pycdio.MIN_CDTEXT_FIELD, pycdio.MAX_CDTEXT_FIELDS):
+            value = cdt.get(i, t)
+            # value can be empty but exist, compared to NULL values
+            if value is not None:
+                print("\t%s: %s" % (pycdio.cdtext_field2str(i), value))
+                pass
+            pass
+        pass
+    return
 
 if sys.argv[1:]:
     try:
         drive_name = sys.argv[1]
         d = cdio.Device(sys.argv[1])
     except IOError:
-        print "Problem opening CD-ROM: %s" % drive_name
+        print("Problem opening CD-ROM: %s" % drive_name)
         sys.exit(1)
 else:
     try:
         d = cdio.Device(driver_id=pycdio.DRIVER_UNKNOWN)
         drive_name = d.get_device()
     except IOError:
-        print "Problem finding a CD-ROM"
+        print("Problem finding a CD-ROM")
         sys.exit(1)
 
-i_tracks = d.get_num_tracks()
-i_first_track = pycdio.get_first_track_num(d.cd)
-
-print_cdtext_track_info(d, 0, 'CD-Text for Disc:')
-for i in range(i_first_track, i_tracks + i_first_track):
-    print_cdtext_track_info(d, i, 'CD-Text for Track %d:' % i)
+if pycdio.VERSION_NUM < 83:
+    i_tracks = d.get_num_tracks()
+    i_first_track = pycdio.get_first_track_num(d.cd)
+    print_cdtext_track_info_old(d, 0, 'CD-Text for Disc:')
+    for i in range(i_first_track, i_tracks + i_first_track):
+        print_cdtext_track_info_old(d, i, 'CD-Text for Track %d:' % i)
+        pass
+    pass
+else:
+    print_cdtext_info_new(d, 'CD-Text for disk')
+    pass
